@@ -16,7 +16,7 @@ test_that(
     )
     outpath <- file.path(
       tempdir(), "MODIStsp/spatial_file/",
-      "/Surf_Temp_8Days_GridSin_v6/LST_Day_6km/MOD11B2_LST_Day_6km_2017_001.tif"
+      "/Surf_Temp_8Days_GridSin_v61/LST_Day_6km/MOD11B2_LST_Day_6km_2017_001.tif"
     )
     outrast     <- suppressWarnings(raster::raster(outpath))
     ext_mstpout <- sf::st_bbox(outrast)
@@ -27,7 +27,7 @@ test_that(
     # resolution to account for the fact that to include boundaries of the
     # polygon a padding of one pixel is always made)
     expect_equal(as.numeric(ext_mstpout), as.numeric(ext_spin),
-                 tolerance = raster::res(outrast), scale = 1)
+                 tolerance = mean(raster::res(outrast)), scale = 1)
     unlink(outpath)
 
     MODIStsp(test = "07b")
@@ -36,7 +36,7 @@ test_that(
     out_files_tif <- list.files(
       file.path(
         tempdir(),
-        "MODIStsp/Surf_Temp_8Days_GridSin_v6/LST_Day_6km/"),
+        "MODIStsp/Surf_Temp_8Days_GridSin_v61/LST_Day_6km/"),
       pattern = "\\.tif$", recursive = TRUE, full.names = TRUE)
 
     r <- sf::gdal_utils("info", out_files_tif[1], quiet = TRUE)
